==> qt-creator-2.6.2-src.zip: qt-creator-2.6.2-src/src/plugins/texteditor/codeassist/iassistinterface.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef IASSISTINTERFACE_H
#define IASSISTINTERFACE_H

#include "assistenums.h"

#include <texteditor/texteditor_global.h>

#include <QString>

QT_BEGIN_NAMESPACE
class QTextDocument;
class QThread;
QT_END_NAMESPACE

namespace Core {
class IDocument;
}

namespace TextEditor {

class TEXTEDITOR_EXPORT IAssistInterface
{
public:
    IAssistInterface();
    virtual ~IAssistInterface();

    virtual int position() const = 0;
    virtual QChar characterAt(int position) const = 0;
    virtual QString textAt(int position, int length) const = 0;
    virtual const Core::IDocument *document() const = 0;
    virtual QTextDocument *textDocument() const = 0;
    virtual void detach(QThread *destination) = 0;
    virtual AssistReason reason() const = 0;
};

} // TextEditor

#endif // IASSISTINTERFACE_H

==> qt-creator-2.7.1-src.zip: qt-creator-2.7.1-src/src/plugins/texteditor/codeassist/iassistinterface.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef IASSISTINTERFACE_H
#define IASSISTINTERFACE_H

#include "assistenums.h"

#include <texteditor/texteditor_global.h>

#include <QString>

QT_BEGIN_NAMESPACE
class QTextDocument;
class QThread;
QT_END_NAMESPACE

namespace Core {
class IDocument;
}

namespace TextEditor {

class TEXTEDITOR_EXPORT IAssistInterface
{
public:
    IAssistInterface();
    virtual ~IAssistInterface();

    virtual int position() const = 0;
    virtual QChar characterAt(int position) const = 0;
    virtual QString textAt(int position, int length) const = 0;
    virtual const Core::IDocument *document() const = 0;
    virtual QTextDocument *textDocument() const = 0;
    virtual void prepareForAsyncUse() = 0;
    virtual void recreateTextDocument() = 0;
    virtual AssistReason reason() const = 0;
};

} // TextEditor

#endif // IASSISTINTERFACE_H
